<?php
namespace App\Exports;

use Maatwebsite\Excel\Concerns\WithMultipleSheets;

class JobExport implements WithMultipleSheets
{
    protected $jobs;

    public function __construct($jobs)
    {
        $this->jobs = $jobs;
    }

    public function sheets(): array
    {
        return [
            new JobDetailsSheet($this->jobs),
            new WasteDetailsSheet($this->jobs),
        ];
    }
}

// JobDetailsSheet
namespace App\Exports;

use Maatwebsite\Excel\Concerns\FromArray;
use Maatwebsite\Excel\Concerns\WithHeadings;

class JobDetailsSheet implements FromArray, WithHeadings
{
    protected $jobs;

    public function __construct($jobs)
    {
        $this->jobs = $jobs;
    }

    public function array(): array
    {
        $data = [];

        foreach ($this->jobs as $job) {
            $lengths = json_decode($job['length']);
            foreach ($lengths as $index => $length) {
                $usedPiece = $job['used_pieces'][$index];
                $data[] = [
                    'Job Length' => $length . ' mm',
                    'Used Pieces' => $usedPiece['length'] . ' mm / ' . $usedPiece['qty'] . ' pc' . ($usedPiece['type'] === 'waste' ? ' (From waste)' : ' (From stock)'),
                ];
            }
        }

        return $data;
    }

    public function headings(): array
    {
        return ['Job Length', 'Used Pieces'];
    }
}

// WasteDetailsSheet
namespace App\Exports;

use Maatwebsite\Excel\Concerns\FromArray;
use Maatwebsite\Excel\Concerns\WithHeadings;

class WasteDetailsSheet implements FromArray, WithHeadings
{
    protected $jobs;

    public function __construct($jobs)
    {
        $this->jobs = $jobs;
    }

    public function array(): array
    {
        $data = [];

        foreach ($this->jobs as $job) {
            $lengths = json_decode($job['length']);
            foreach ($lengths as $index => $length) {
                $wasteLength = $job['wastes'][$index]['length'] ?? 0;
                $data[] = [
                    'Job Length' => $length . ' mm',
                    'Waste Length' => $wasteLength . ' mm',
                ];
            }
        }

        return $data;
    }

    public function headings(): array
    {
        return ['Job Length', 'Waste Length'];
    }
}
