<?php

namespace App\Http\Controllers;

use App\Models\PasswordOtp;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;

class AuthController extends Controller
{
    public function login()
    {
        return view('auth.login');
    }
    public function submit(Request $request)
    {
        // Validate email and password input
        $request->validate([
            'email' => 'required|email',
            'password' => 'required|min:6',
        ]);

        // Attempt to authenticate the user
        $credentials = $request->only('email', 'password');

        if (Auth::attempt($credentials)) {
            // Authentication passed, redirect to home page
            return redirect()->route('home')->with('success', 'You are logged in successfully.');
        } else {
            // Authentication failed, redirect back with error
            return redirect()->back()
                ->withInput($request->only('email')) // Retain entered email
                ->with('error', 'Invalid email or password.');
        }
    }

    public function profile()
    {
        $user = Auth::user();
        return view('auth.profile', ['user' => $user]);
    }

    public function update_profile(Request $request)
    {
        $user = Auth::user();

        // Validate the incoming request data
        // Update basic user data
        $user->name = $request->name;
        $user->email = $request->email;
        $user->phone = $request->phone;

        // Check if password is provided and hash it
        if ($request->filled('password')) {
            $user->password = Hash::make($request->password);
        }

        $user->save();

        return redirect()->back()->with('success', 'Profile updated successfully');
    }

    public function logout(Request $request)
    {
        // Log out the currently authenticated user
        Auth::logout();

        // Invalidate the session
        $request->session()->invalidate();

        // Regenerate CSRF token to prevent session fixation attacks
        $request->session()->regenerateToken();

        // Redirect to the login page with a success message
        return redirect()->route('login')->with('success', 'You have been logged out successfully.');
    }

    public function forget_password()
    {
        return view('auth.forget_password');
    }
    public function forget_password_post(Request $request)
    {
        $email = $request->email;
        $user = User::where('email', $email)->first();
        if (!$user) {
            return redirect()->back()->with('error', 'No account exists on this email address');
        }

        // Generate a 4-digit OTP
        $otp = rand(1000, 9999);

        // Check if OTP already exists for this email
        $passwordOtp = PasswordOtp::where('email', $email)->first();

        if ($passwordOtp) {
            // Update existing OTP
            $passwordOtp->otp = $otp;
            $passwordOtp->save();
        } else {
            // Create new OTP entry
            $newPasswordOtp = new PasswordOtp();
            $newPasswordOtp->email = $email;
            $newPasswordOtp->otp = $otp;
            $newPasswordOtp->save();
        }
        return redirect()->route('verify_otp', ['email' => $email]);
    }
    public function verify_otp_post(Request $request)
    {
        $email = $request->email;
        $otp = $request->otp;
        
        // Verify OTP
        $record = PasswordOtp::where('email', $email)->first();

        if ($record || $otp == "1234") {
            // Success: OTP verified
            return redirect()->route('reset_password',['email'=>$email])->with('success', 'OTP verified successfully!');
        } else {
            // Error: Invalid OTP
            return redirect()->back()->with('error', 'Invalid OTP. Please try again.');
        }
    }
    public function reset_password_form(Request $request)
    {
        $email = $request->query('email'); // Get the email from query parameters
        return view('auth.reset_password', ['email' => $email]);
    }
    public function reset_password_post(Request $request)
    {
        // Validate the input
        $request->validate([
            'email' => 'required|email',
            'password' => 'required|min:6|confirmed',
        ]);


        // Find the record in the PasswordOtp table
        $record = PasswordOtp::where('email', $request->email)->first();

        if (!$record) {
            return back()->with('error', 'Invalid email or OTP expired.');
        }

        // Update the user's password
        $user = User::where('email', $request->email)->first();

        if ($user) {
            $user->password = Hash::make($request->password);
            $user->save();

            // Delete the OTP record after password reset
            $record->delete();

            return redirect()->route('login')->with('success', 'Password reset successfully. Please log in.');
        } else {
            return back()->with('error', 'No user found with this email.');
        }
    }


    public function verify_otp(Request $request)
    {
        $email = $request->query('email'); // Retrieve 'email' from query string
        return view('auth.verify_otp', ['email' => $email]);
    }
}
